# Earth Data Fetcher

A simple package to fetch gridded earth data from different sources using the appropriate protocol. 

Supports the following protocols:
- HTTP[S]
- FTP
- S3
- THREDDS datasets
- CMEMS datasets

## To do

The majority of my datasets are hosted on CMEMS, so those will be prioritized.
The HTTP[S] protocol will be the next to be implemented since the SST and MLD (SODA) data are hosted on HTTP servers.